@@ -5,8 +5,9 @@ import copy
 import thornpy
 from . import TMPLT_ENV
 from .utilities import read_TO_file, get_cdb_path, get_full_path
+
 class DrillHole():
-    """An object with all teh data necessary to write an Adams Drill hole (.hol) file.
+    """An object with all the data necessary to write an Adams Drill hole (.hol) file.
     
     Parameters
     ----------
@@ -302,6 +303,23 @@ class DrillHole():
         """
         self.parameters[param_name] = copy.deepcopy(values)
         self.parameters[f'_{param_name}'] = zip(*self.parameters[param_name])
+    
+    def get_tvd(self, md):
+        """Returns the true vertical depth (TVD) corresponding to the provided measured depth (MD).
+        
+        Parameters
+        ----------
+        md : float
+            Measured depth for which true vertical depth should be returned
+        
+        Returns
+        -------
+        float
+            True vertical depth corresponding to the given measured depth
+            
+        """
+        tvd = md
+        return tvd
 
     def _get_params_from_TO_data(self, tiem_orbit_data):
         """Reads the hole parameters out of a dictoinary of Tiem Orbit data generated by :func:`adamspy.adripy.utilities.read_TO_file`
